@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import math
 import os.path
 from gettext import gettext as _
@@ -46,6 +47,34 @@ WHITE_SQUARE_COLOURS = {None:                               (1.0, 1.0, 1.0),
                         glchess.scene.HIGHLIGHT_THREATENED: (1.0, 0.8, 0.8),
                         glchess.scene.HIGHLIGHT_CAN_TAKE:   (1.0, 0.2, 0.2)}
 
+import math
+def accFrustum(left, right, bottom, top,
+               near, far,
+               pixdx, pixdy,
+               eyedx, eyedy, 
+               focus):
+    viewport = glGetIntegerv(GL_VIEWPORT)
+
+    xwsize = right - left
+    ywsize = top - bottom
+    dx = -(pixdx*xwsize/viewport[2] + eyedx*near/focus)
+    dy = -(pixdy*ywsize/viewport[3] + eyedy*near/focus)
+
+    glFrustum(left + dx, right + dx, bottom + dy, top + dy, near, far)
+    glTranslatef(-eyedx, -eyedy, 0.0)
+
+def accPerspective(fovy, aspect,
+                   near, far,
+                   pixdx, pixdy,
+                   eyedx, eyedy, 
+                   focus):
+    fov2 = ((fovy*math.pi) / 180.0) / 2.0
+    top = near / (math.cos(fov2) / math.sin(fov2))
+    bottom = -top
+    right = top * aspect
+    left = -right
+    accFrustum(left, right, bottom, top, near, far, pixdx, pixdy, eyedx, eyedy, focus)
+
 class ChessPiece(glchess.scene.ChessPiece):
     """
     """    
@@ -188,6 +217,8 @@ class Scene(glchess.scene.Scene):
     highlights       = None
     
     _animationQueue  = []
+    
+    jitters = ((0.0, 0.0),)
 
     showNumbering = False
     numberingTexture = None
@@ -253,7 +284,16 @@ class Scene(glchess.scene.Scene):
         """Extends glchess.scene.Scene"""
         self.showNumbering = showNumbering
         self.feedback.onRedraw()
-    
+
+    def showSmooth(self, doSmooth):
+        if doSmooth:
+            #self.jitters = ((-0.25, 0.25), (0.25, -0.25))
+            self.jitters = ((0.0033922635, 0.3317967229), (0.2806016275, -0.2495619123), (-0.273817106, -0.086844639))
+            #self.jitters = ((-0.175, -0.25), (-0.375, 0.25), (0.375, -0.25), (0.125, 0.25))
+        else:
+            self.jitters = ((0.0, 0.0),)
+        self.feedback.onRedraw()
+
     def reshape(self, width, height):
         """Resize the viewport into the scene.
         
@@ -263,6 +303,7 @@ class Scene(glchess.scene.Scene):
         self.viewportWidth = int(width)
         self.viewportHeight = int(height)
         self.viewportAspect = float(self.viewportWidth) / float(self.viewportHeight)
+        glViewport(0, 0, self.viewportWidth, self.viewportHeight)
         self.feedback.onRedraw()
 
     def setBoardRotation(self, angle, animate = True):
@@ -299,46 +340,61 @@ class Scene(glchess.scene.Scene):
         This requires an OpenGL context.
         """
         glClearColor(*BACKGROUND_COLOUR)
-        glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
-
-        # Set the projection for this scene
-        self.setViewport()
-
-        # Do camera and board rotation/translation
-        glEnable(GL_DEPTH_TEST)
-        glMatrixMode(GL_MODELVIEW)
-        glLoadIdentity()
-        self.transformCamera()
+        if len(self.jitters) > 1:
+            glClear(GL_ACCUM_BUFFER_BIT)
         
         glLightfv(GL_LIGHT0, GL_AMBIENT, LIGHT_AMBIENT_COLOUR)
         glLightfv(GL_LIGHT0, GL_DIFFUSE, LIGHT_DIFFUSE_COLOUR)
         glLightfv(GL_LIGHT0, GL_SPECULAR, LIGHT_SPECULAR_COLOUR)
-        glLightfv(GL_LIGHT0, GL_POSITION, self.lightPos)
-        glEnable(GL_LIGHTING)
-        glEnable(GL_LIGHT0)
         
-        self.transformBoard()
-    
-        glEnable(GL_DEPTH_TEST)
-        glEnable(GL_CULL_FACE)
+        for jitter in self.jitters:
+            glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
+            
+            # Set the projection for this scene
+            glMatrixMode(GL_PROJECTION)
+            glLoadIdentity()
+            if len(self.jitters) > 1:
+                accPerspective(60.0, self.viewportAspect, 0.1, 1000, jitter[0], jitter[1], 0, 0, 1)
+            else:
+                gluPerspective(60.0, self.viewportAspect, 0.1, 1000)
+
+            # Do camera and board rotation/translation
+            glMatrixMode(GL_MODELVIEW)
+            glLoadIdentity()
+            self.transformCamera()
+
+            glLightfv(GL_LIGHT0, GL_POSITION, self.lightPos)            
+            glEnable(GL_LIGHTING)
+            glEnable(GL_LIGHT0)
+            
+            self.transformBoard()
+            
+            glEnable(GL_DEPTH_TEST)
+            glEnable(GL_CULL_FACE)
         
-        glEnable(GL_TEXTURE_2D)
-        glEnable(GL_COLOR_MATERIAL)
-        self.drawBoard()
-        glDisable(GL_COLOR_MATERIAL)
-        glDisable(GL_TEXTURE_2D)
+            glEnable(GL_TEXTURE_2D)
+            glEnable(GL_COLOR_MATERIAL)
+            self.drawBoard()
+            glDisable(GL_COLOR_MATERIAL)
+            glDisable(GL_TEXTURE_2D)
         
-        if self.showNumbering:
-            self.drawNumbering()
+            if self.showNumbering:
+                self.drawNumbering()
         
-        # WORKAROUND: Mesa is corrupting polygons on the bottom of the models
-        # It could be because the depth buffer has a low bit depth?
-        glClear(GL_DEPTH_BUFFER_BIT)
+            # WORKAROUND: Mesa is corrupting polygons on the bottom of the models
+            # It could be because the depth buffer has a low bit depth?
+            glClear(GL_DEPTH_BUFFER_BIT)
         
-        if self.throbberEnabled:
-            self.drawThrobber()
-        else:
-            self.drawPieces()
+            if self.throbberEnabled:
+                self.drawThrobber()
+            else:
+                self.drawPieces()
+            
+            if len(self.jitters) > 1:
+                glAccum(GL_ACCUM, 1.0 / len(self.jitters))
+
+        if len(self.jitters) > 1:
+            glAccum(GL_RETURN, 1)
             
     def getSquare(self, x, y):
         """Find the chess square at a given 2D location.
@@ -356,20 +412,10 @@ class Scene(glchess.scene.Scene):
         # Don't render to screen, just select
         # Selection buffer is large in case we select multiple squares at once (it generates an exception)
         glSelectBuffer(20)
-        
-        # TEMP
-        # Handle the failure case in bug #538252. By catching this we convert a crash
-        # that would generate bugzilla report into the user input being ignored. This should
-        # be removed once the problem has been fixed (assumed to be in PyGTK/OpenGL drivers).
-        # Note that OpenGL may be in an invalid state when this fails.
-        try:
-            glRenderMode(GL_SELECT)
-        except IndexError:
-            print 'Failed to change to GL_SELECT render mode (Bug #538252)'
-            return None
+        glRenderMode(GL_SELECT)
 
         glInitNames()
-
+        
         # Create pixel picking region near cursor location
         glMatrixMode(GL_PROJECTION)
         glLoadIdentity()
@@ -407,14 +453,6 @@ class Scene(glchess.scene.Scene):
         if coord is None:
             return None
         
-        # TEMP
-        # Handle the failure case in bug #535256. By catching this we convert a crash
-        # that would generate bugzilla report into the user input being ignored. This should
-        # be removed once the problem has been fixed (assumed to be in PyGTK/OpenGL drivers).
-        if len(coord) != 2:
-            print 'Invalid response received from glRenderMode(GL_RENDER) (Bug #535256): coord=%s, viewport=%s' % (repr(coord), repr(viewport))
-            return None
-
         # Convert from co-ordinates to LAN format
         rank = chr(ord('a') + coord[0])
         file = chr(ord('1') + coord[1])
@@ -582,13 +620,6 @@ class Scene(glchess.scene.Scene):
             
         glDisable(GL_BLEND)
 
-    def setViewport(self):
-        """Perform the projection matrix transformation for the current viewport"""
-        glViewport(0, 0, self.viewportWidth, self.viewportHeight)
-        glMatrixMode(GL_PROJECTION)
-        glLoadIdentity()
-        gluPerspective(60.0, self.viewportAspect, 0.1, 1000)
-
     def transformCamera(self):
         """Perform the camera matrix transformation"""
         gluLookAt(0.0, 90.0, 45.0,
@@ -601,11 +632,6 @@ class Scene(glchess.scene.Scene):
         TEXTURE_WIDTH = WIDTH*16
         TEXTURE_HEIGHT = HEIGHT
 
-        # Chess board columns (files) label marked for translation. Please translate to the first eight letters of your alphabet, or the most appropriate eight characters/symbols for labelling the columns of a chess board. 
-        files = [_('a'), _('b'), _('c'), _('d'), _('e'), _('f'), _('g'), _('h')]
-        # Chess board rows (ranks) label marked for translation. Please translate to the first eight numbers with your native number symbols, or the most appropriate eight numbers/symbols for labelling the rows of a chess board.
-        ranks = [_('1'), _('2'), _('3'), _('4'), _('5'), _('6'), _('7'), _('8')]
-
         surface = cairo.ImageSurface(cairo.FORMAT_A8, TEXTURE_WIDTH, TEXTURE_HEIGHT)
         context = cairo.Context(surface)
         context.set_source_rgba(1.0, 1.0, 1.0, 1.0)
@@ -623,13 +649,14 @@ class Scene(glchess.scene.Scene):
             context.show_text(text)
             context.set_matrix(matrix)
 
-        xoffset = WIDTH * 0.5
         yoffset = HEIGHT * 0.5
+        xoffset = WIDTH * 0.5
         for i in xrange(8):
-            drawCenteredText(xoffset, yoffset, scale, files[i])
-            drawCenteredText(xoffset + (WIDTH * 8), yoffset, scale, ranks[i])
+            f = 'abcdefgh'[i]
+            r = '12345678'[i]
+            drawCenteredText(xoffset, yoffset, scale, glchess.chess.translate_file(f))
+            drawCenteredText(xoffset + (WIDTH * 8), yoffset, scale, glchess.chess.translate_rank(r))
             xoffset += WIDTH
-        data = surface.get_data()
 
         t = glGenTextures(1)
         glBindTexture(GL_TEXTURE_2D, t)
@@ -638,7 +665,8 @@ class Scene(glchess.scene.Scene):
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT)
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR)
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR)
-        
+
+        data = surface.get_data()        
         try:
             gluBuild2DMipmaps(GL_TEXTURE_2D, GL_ALPHA, TEXTURE_WIDTH, TEXTURE_HEIGHT,
                               GL_ALPHA, GL_UNSIGNED_BYTE, str(data))
