@@ -23,7 +23,10 @@
 #include <config.h>
 #endif
 
-#include <games-sound.h>
+#include <stdlib.h>
+#include <ctype.h>
+
+#include <libgames-support/games-sound.h>
 
 #include "worm.h"
 #include "gnibbles.h"
