@@ -19,6 +19,7 @@
  * For more details see the file COPYING.
  */
 
+#include <config.h>
 #include "blockops.h"
 #include "blocks.h"
 
@@ -38,7 +39,7 @@ BlockOps::BlockOps() :
 	color (0)
 {
 	field = new Block*[COLUMNS];
-	
+
 	posx = COLUMNS / 2;
 	posy = 0;
 
@@ -52,11 +53,11 @@ BlockOps::~BlockOps()
 {
 	for (int i = 0; i < COLUMNS; ++i)
 		delete[] field[i];
-	
+
 	delete[] field;
 }
 
-bool 
+bool
 BlockOps::blockOkHere(int x, int y, int b, int r)
 {
 	x -= 2;
@@ -76,14 +77,14 @@ BlockOps::blockOkHere(int x, int y, int b, int r)
 		}
 	}
 
-	return true;	
+	return true;
 }
 
 int
 BlockOps::getLinesToBottom()
 {
 	int lines = LINES;
-	
+
 	for (int x = 0; x < 4; ++x)
 	{
 		for (int y = 3; y >= 0; --y)
@@ -105,7 +106,7 @@ BlockOps::getLinesToBottom()
 	return lines;
 }
 
-bool 
+bool
 BlockOps::moveBlockLeft()
 {
 	bool moved = false;
@@ -117,11 +118,11 @@ BlockOps::moveBlockLeft()
 		putBlockInField(false);
 		moved = true;
 	}
-	
+
 	return moved;
 }
 
-bool 
+bool
 BlockOps::moveBlockRight()
 {
 	bool moved = false;
@@ -133,7 +134,7 @@ BlockOps::moveBlockRight()
 		putBlockInField(false);
 		moved = true;
 	}
-	
+
 	return moved;
 }
 
@@ -141,9 +142,9 @@ bool
 BlockOps::rotateBlock(bool rotateCCW)
 {
 	bool moved = false;
-	
+
 	int r = rot;
-	
+
 	if ( rotateCCW )
 	{
 		if (--r < 0) r = 3;
@@ -152,7 +153,7 @@ BlockOps::rotateBlock(bool rotateCCW)
 	{
 		if (++r >= 4) r = 0;
 	}
-		
+
 	if (blockOkHere(posx, posy, blocknr, r))
 	{
 		putBlockInField(true);
@@ -160,11 +161,11 @@ BlockOps::rotateBlock(bool rotateCCW)
 		putBlockInField(false);
 		moved = true;
 	}
-	
+
 	return moved;
 }
 
-bool 
+bool
 BlockOps::moveBlockDown()
 {
 	bool fallen = false;
@@ -178,11 +179,11 @@ BlockOps::moveBlockDown()
 		++posy;
 		putBlockInField(false);
 	}
-	
+
 	return fallen;
 }
 
-void 
+void
 BlockOps::clearTarget ()
 {
 	for (int x = 0; x < COLUMNS; ++x)
@@ -202,7 +203,7 @@ BlockOps::generateTarget ()
 	clearTarget ();
 
 	// FIXME: Check that this is actually guaranteed
-	// to terminate (i.e. posx, posy, blocknr and rot 
+	// to terminate (i.e. posx, posy, blocknr and rot
 	// are guaranteed to be valid).
 	int n = 0;
 	do {
@@ -214,7 +215,7 @@ BlockOps::generateTarget ()
 	putBlockInField (posx, posy + n, blocknr, rot, TARGET);
 }
 
-void 
+void
 BlockOps::setUseTarget (bool use)
 {
 	useTarget = use;
@@ -306,12 +307,12 @@ BlockOps::generateFallingBlock()
 	int cn = random_block_colors ? g_random_int_range(0, NCOLOURS) :
 		blocknr % NCOLOURS;
 	color = color_next == -1 ? cn : color_next;
-	
+
 	blocknr_next = g_random_int_range(0, tableSize);
 	rot_next = g_random_int_range(0, 4);
 	color_next = random_block_colors ? g_random_int_range(0, NCOLOURS) :
 		blocknr_next % NCOLOURS;
-	
+
 	if (!blockOkHere(posx, posy, blocknr, rot))
 		return false;
 
@@ -331,12 +332,12 @@ BlockOps::emptyField(int filled_lines, int fill_prob)
 		for (int x = 0; x < COLUMNS; ++x)
 		{
 			field[x][y].what = EMPTY;
-			field[x][y].color = 0; 
+			field[x][y].color = 0;
 
 			if ((y>=(LINES - filled_lines)) && (x != blank) &&
-			    ((g_random_int_range(0, 10)) < fill_prob)) { 
+			    ((g_random_int_range(0, 10)) < fill_prob)) {
 				field[x][y].what = LAYING;
-				field[x][y].color = 
+				field[x][y].color =
 				  g_random_int_range(0, NCOLOURS);
 			}
 		}
@@ -362,7 +363,7 @@ BlockOps::putBlockInField (int bx, int by, int block, int rotation,
 				int i = bx - 2 + x;
 				int j = y + by;
 
-				if ((fill == TARGET) && 
+				if ((fill == TARGET) &&
 				    (field[i][j].what != EMPTY))
 					return;
 
