@@ -99,7 +99,8 @@ gint current_level = -1;
 guint redraw_all_idle_id = 0;
 guint configure_idle_id = 0;
 
-static const GamesScoresCategory scorecats[] = { {"1", N_("Only 18 steps")},
+static const GamesScoresCategory scorecats[] = {
+{"1", N_("Only 18 steps")},
 {"2", N_("Daisy")},
 {"3", N_("Violet")},
 {"4", N_("Poppy")},
@@ -126,14 +127,7 @@ static const GamesScoresCategory scorecats[] = { {"1", N_("Only 18 steps")},
 {"25", N_("Baltic Sea")},
 {"26", N_("American Pie")},
 {"27", N_("Traffic Jam")},
-{"28", N_("Sunshine")},
-GAMES_SCORES_LAST_CATEGORY
-};
-
-static const GamesScoresDescription scoredesc = { scorecats,
-  "1",
-  "gnotski",
-  GAMES_SCORES_STYLE_PLAIN_ASCENDING
+{"28", N_("Sunshine")}
 };
 
 GamesScores *highscores;
@@ -491,22 +485,11 @@ main (int argc, char **argv)
   EggSMClient *sm_client;
 #endif /* WITH_SMCLIENT */
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
-   * calling any glib functions.
-   */
-  g_thread_init (NULL);
-#endif
-
   if (!games_runtime_init ("gnotski"))
     return 1;
 
   setgid_io_init ();
 
-  bindtextdomain (GETTEXT_PACKAGE, games_runtime_get_directory (GAMES_RUNTIME_LOCALE_DIRECTORY));
-  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-  textdomain (GETTEXT_PACKAGE);
-
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
   g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
@@ -541,7 +524,11 @@ main (int argc, char **argv)
                     G_CALLBACK (quit_cb), NULL);
 #endif /* WITH_SMCLIENT */
 
-  highscores = games_scores_new (&scoredesc);
+  highscores = games_scores_new ("gnotski",
+                                 scorecats, G_N_ELEMENTS (scorecats),
+                                 NULL, NULL,
+                                 0 /* default category */,
+                                 GAMES_SCORES_STYLE_PLAIN_ASCENDING);
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), _(APPNAME_LONG));
@@ -851,6 +838,7 @@ show_score_dialog (gint pos, gboolean endofgame)
 				       pos);
       message = g_strdup_printf ("<b>%s</b>\n\n%s",
 				 _("Congratulations!"),
+                                 pos == 1 ? _("Your score is the best!") :
 				 _("Your score has made the top ten."));
       games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
 				       message);
@@ -883,18 +871,6 @@ score_cb (GtkAction * action)
   show_score_dialog (0, FALSE);
 }
 
-static void
-update_score_state (void)
-{
-  GtkAction *score_action;
-  GList *top;
-
-  score_action = gtk_action_group_get_action (action_group, "Scores");
-  top = games_scores_get (highscores);
-  gtk_action_set_sensitive (score_action, top != NULL);
-
-}
-
 void
 game_score ()
 {
@@ -910,7 +886,6 @@ game_score ()
 
   score.plain = (guint32) moves;
   pos = games_scores_add_score (highscores, score);
-  update_score_state ();
   if (show_score_dialog (pos, TRUE) == GTK_RESPONSE_REJECT)
     gtk_main_quit ();
   else
@@ -1462,7 +1437,6 @@ new_game (gint requested_level)
   games_grid_frame_set (GAMES_GRID_FRAME (gameframe), width, height);
   configure_pixmaps ();
   update_menu_state ();
-  update_score_state ();
 }
 
 void
